@@ -45,7 +45,7 @@ my %scriptdir = (
     'Latin8'        => 'xt',
     'Latin9'        => 'xt',
     'OldUTF8'       => 'xt',
-### 'Sjis'          =>  't',
+    'Sjis'          =>  't',
     'TIS620'        => 'xt',
     'UHC'           => 'xt',
     'USASCII'       => 'xt',
@@ -58,8 +58,6 @@ open(MANIFEST,">MANIFEST.add") || die "Can't open file: MANIFEST.add\n";
 binmode MANIFEST;
 
 for my $dist (sort keys %scriptdir) {
-    next if $dist eq 'Sjis';
-
     my @test = ();
     if (opendir(DIR,qq{t/$dist})) {
         push @test, map {"t/$dist/$_"} grep(/\.t$/i, readdir(DIR));
